jQuery(document).ready(function() {

	//Vars
	var body = jQuery('body');
	var overlay = jQuery('#wpoffcanvaspanels_overlay');
	var currentPanel = null;
	var windowHeight = 0;
	var windowWidth = 0;
	var jWindow = jQuery(window);
	var sidePanels = jQuery('.wpoffcanvaspanels_panel.wpoffcanvaspanels_left, .wpoffcanvaspanels_panel.wpoffcanvaspanels_right');

	//Touch check
	function is_touch_device() {
		try {
			document.createEvent("TouchEvent");
			return true;
		} catch (e) {
			return false;
		}
	}

	//Animation support
	function animation_supported() {
		var el = document.createElement('p'),
				has3d,
				transforms = {
			'webkitTransform': '-webkit-transform',
			'OTransform': '-o-transform',
			'msTransform': '-ms-transform',
			'MozTransform': '-moz-transform',
			'transform': 'transform'
		};
		document.body.insertBefore(el, null);
		for (var t in transforms) {
			if (el.style[t] !== undefined) {
				el.style[t] = "translate3d(1px,1px,1px)";
				has3d = window.getComputedStyle(el).getPropertyValue(transforms[t]);
			}
		}
		document.body.removeChild(el);
		return (has3d !== undefined && has3d.length > 0 && has3d !== "none");
	}

	/*Show menu*/
	function togglePanel(panel, viaButton) {
		//Check if currentpanel is different then panel
		if (currentPanel && currentPanel[0] != panel[0]) {
			togglePanel(currentPanel, false);
		}
		//Vars
		var animation = panel.data('animation');
		var side = panel.data('side');
		var showOverlay = panel.data('overlay');
		var animationClass = 'wpoffcanvaspanels_' + animation;
		var sideClass = 'wpoffcanvaspanels_' + side;
		if (body.hasClass('wpoffcanvaspanels_show')) {
			//Animate out
			body.removeClass('wpoffcanvaspanels_show');
			body.removeClass(sideClass);
			body.removeClass(animationClass);
			if (animationClass == 'wpoffcanvaspanels_reveal' || animationClass.indexOf('push') != -1) {
				body.attr('style', function(i, style) {
					if (!style) {
						style = '';
					}
					return style.replace(/margin[^;]+;?/g, '');
				});
				if (overlay) {
					overlay.attr('style', function(i, style) {
						if (!style) {
							style = '';
						}
						style = style.replace(/top[^;]+;?/g, '');
						return style.replace(/left[^;]+;?/g, '');
					});
				}
			}
			jQuery('.wpoffcanvaspanels_button[data-target="' + sideClass + '"]').delay(500).fadeIn();
			if (overlay) {
				overlay.stop(true, false).fadeOut();
			}
			if (togglePanelFallback) {
				togglePanelFallback(panel);
			}
			currentPanel.data('viabutton', null);
			currentPanel = null;
		} else {
			//Animate in
			body.addClass('wpoffcanvaspanels_show');
			body.addClass(sideClass);
			body.addClass(animationClass);
			if (animationClass == 'wpoffcanvaspanels_reveal' || animationClass.indexOf('push') != -1) {
				switch (sideClass) {
					case 'wpoffcanvaspanels_left':
						body.css('margin', '0 0 0 ' + panel.outerWidth() + 'px');
						if (overlay && showOverlay) {
							overlay.css('left', panel.outerHeight() + 'px');
						}
						break;
					case 'wpoffcanvaspanels_right':
						body.css('margin', '0 0 0 -' + panel.outerWidth() + 'px');
						if (overlay && showOverlay) {
							overlay.css('left', (-panel.outerHeight()) + 'px');
						}
						break;
					case 'wpoffcanvaspanels_top':
						body.css('margin', panel.outerHeight() + 'px 0 0 0');
						if (overlay && showOverlay) {
							overlay.css('top', panel.outerHeight() + 'px');
						}
						break;
					case 'wpoffcanvaspanels_bottom':
						body.css('margin', '0 0 ' + panel.outerHeight() + 'px 0');
						if (overlay && showOverlay) {
							overlay.css('top', (-panel.outerHeight()) + 'px');
						}
						break;
				}
			}
			jQuery('.wpoffcanvaspanels_button[data-target="' + sideClass + '"]').hide();
			if (overlay && showOverlay) {
				overlay.stop(true, false).fadeIn();
			}
			if (togglePanelFallback) {
				togglePanelFallback(panel);
			}
			if (viaButton === true) {
				panel.data('viabutton', 'true');
			} else {
				panel.data('viabutton', 'false');
			}
			currentPanel = panel;
		}
	}

	/*Buttons*/
	jQuery('.wpoffcanvaspanels_button').click(function(e) {
		e.preventDefault();
		var target = jQuery(this).data('target');
		if (!target) {
			return false;
		}
		togglePanel(jQuery('.' + target), true);
	});

	/*Overlay*/
	if (overlay) {
		overlay.click(function(e) {
			e.preventDefault();
			if (currentPanel) {
				togglePanel(currentPanel, true);
			}
		});
	}

	/*Close buttons*/
	jQuery('.wpoffcanvaspanels_panel .wpoffcanvaspanels_close').click(function(e) {
		e.preventDefault();
		if (currentPanel) {
			togglePanel(currentPanel, true);
		}
	});

	/*Links*/
	//left
	jQuery('a[href="#wp-off-canvas-panels-left"]').click(function(e) {
		e.preventDefault();
		var target = jQuery('.wpoffcanvaspanels_panel.wpoffcanvaspanels_left');
		if (target) {
			togglePanel(target, true);
		}
	});
	//right
	jQuery('a[href="#wp-off-canvas-panels-right"]').click(function(e) {
		e.preventDefault();
		var target = jQuery('.wpoffcanvaspanels_panel.wpoffcanvaspanels_right');
		if (target) {
			togglePanel(target, true);
		}
	});
	//top
	jQuery('a[href="#wp-off-canvas-panels-top"]').click(function(e) {
		e.preventDefault();
		var target = jQuery('.wpoffcanvaspanels_panel.wpoffcanvaspanels_top');
		if (target) {
			togglePanel(target, true);
		}
	});
	//bottom
	jQuery('a[href="#wp-off-canvas-panels-bottom"]').click(function(e) {
		e.preventDefault();
		var target = jQuery('.wpoffcanvaspanels_panel.wpoffcanvaspanels_bottom');
		if (target) {
			togglePanel(target, true);
		}
	});

	/*Show when near*/
	var defaultShowWhenNearOffset = 50;
	var showWhenNearOffset = defaultShowWhenNearOffset;
	function onWindowResize(e) {
		windowHeight = jWindow.height();
		windowWidth = jWindow.width();
		body.css('width', windowWidth + 'px');
		var topCenter = jQuery('.wpoffcanvaspanels_button.wpoffcanvaspanels_top-center');
		var bottomCenter = jQuery('.wpoffcanvaspanels_button.wpoffcanvaspanels_bottom-center');
		topCenter.css('marginLeft', (-Math.round(topCenter.width() / 2)) + 'px');
		bottomCenter.css('marginLeft', (-Math.round(bottomCenter.width() / 2)) + 'px');
	}
	function mouseIsNear(el, mouseX, mouseY) {
		switch (el.data('side')) {
			case 'right':
				if (mouseX >= windowWidth - showWhenNearOffset) {
					showWhenNearOffset = el.width();
					return true;
				}
				break;
			case 'left':
				if (mouseX <= showWhenNearOffset) {
					showWhenNearOffset = el.width();
					return true;
				}
				break;
			case 'top':
				if (mouseY <= showWhenNearOffset) {
					showWhenNearOffset = el.height();
					return true;
				}
				break;
			case 'bottom':
				if (mouseY >= windowHeight - showWhenNearOffset) {
					showWhenNearOffset = el.height();
					return true;
				}
				break;
		}
		return false;
	}
	if (!is_touch_device()) {
		var elementsForNear = jQuery('.wpoffcanvaspanels_panel[data-showwhennear="true"]');
		if (elementsForNear.length > 0) {
			jQuery(document).mousemove(function(e) {
				elementsForNear.each(function() {
					var panel = jQuery(this);
					var viaButton = panel.data('viabutton') === 'true';
					var scrollTop = jWindow.scrollTop();
					var showPanel = mouseIsNear(panel, e.pageX, e.pageY - scrollTop);
					if (showPanel && !currentPanel) {
						togglePanel(panel, false);
					} else if (!viaButton && currentPanel && !showPanel && currentPanel[0] == panel[0]) {
						showWhenNearOffset = defaultShowWhenNearOffset;
						togglePanel(panel, false);
					}
				});
			});
		}
	}
	jWindow.resize(onWindowResize);
	onWindowResize(null);

	//scroll
	function onWindowScroll(e) {
		var scrollTop = jWindow.scrollTop();
		var docHeight = jQuery(document).height();
		var scrollPerc = scrollTop / (docHeight - windowHeight);
		sidePanels.each(function() {
			var _this = jQuery(this);
			var height = _this.prop("scrollHeight");
			if (height > windowHeight) {
				var maxScroll = windowHeight - height;
				var targScroll = -(maxScroll * scrollPerc);
				_this.scrollTop(targScroll);
			}
		});
	}
	if (sidePanels.length > 0) {
		jWindow.scroll(onWindowScroll);
	}

	//fallback
	var togglePanelFallback = null;
	if (!animation_supported()) {
		jQuery("link[id^='wpoffcanvaspanels_animation']").remove();
		togglePanelFallback = function(panel) {
			var panelSide = panel.data('side');
			var animateProps = {};
			if (!body.hasClass('wpoffcanvaspanels_show')) {
				if (panelSide == 'left' || panelSide == 'right') {
					animateProps[panelSide] = (-Math.round(panel.outerWidth(false))) + 'px';
				} else {
					animateProps[panelSide] = (-Math.round(panel.outerHeight(false))) + 'px';
				}
			} else {
				animateProps[panelSide] = '0px';
			}
			panel.stop(true, false).animate(animateProps, 300);
		}
	}

	//links
	jQuery('a').not("[href^='#']").mouseup(function() {
		if (currentPanel) {
			togglePanel(currentPanel, true);
		}
	});

});