<?php
if (!is_admin()) {
	die();
}

include 'wp-styletool/wp-styletool.php';

/**
 * Plugin settings and defaults
 */
$wpoffcanvaspanels_settings = array(
	'enabled_left' => false,
	'size_left' => 300,
	'size_type_left' => 'px',
	'add_close_button_left' => true,
	'show_when_near_left' => false,
	'add_button_left' => true,
	'button_text_left' => 'Open',
	'button_image_left' => '',
	'button_position_left' => 'center-left',
	'overlay_left' => true,
	'animation_left' => 'slide',
	'style_left' => 'default',
	'enabled_right' => false,
	'size_right' => 300,
	'size_type_right' => 'px',
	'add_close_button_right' => true,
	'show_when_near_right' => false,
	'add_button_right' => true,
	'button_text_right' => 'Open',
	'button_image_right' => '',
	'button_position_right' => 'center-right',
	'overlay_right' => true,
	'animation_right' => 'slide',
	'style_right' => 'default',
	'enabled_top' => false,
	'size_top' => 300,
	'size_type_top' => 'px',
	'add_close_button_top' => true,
	'show_when_near_top' => false,
	'add_button_top' => true,
	'button_text_top' => 'Open',
	'button_image_top' => '',
	'button_position_top' => 'top-center',
	'overlay_top' => true,
	'animation_top' => 'slide',
	'style_top' => 'default',
	'enabled_bottom' => false,
	'size_bottom' => 300,
	'size_type_bottom' => 'px',
	'add_close_button_bottom' => true,
	'show_when_near_bottom' => false,
	'add_button_bottom' => true,
	'button_text_bottom' => 'Open',
	'button_image_bottom' => '',
	'button_position_bottom' => 'bottom-center',
	'overlay_bottom' => true,
	'animation_bottom' => 'slide',
	'style_bottom' => 'default'
);

/**
 * Styles
 */
$allThemesOptionName = $style_tool_prefix . 'all_themes';
$allThemes = get_option($allThemesOptionName);
$themesList = array();
$themesList['default'] = 'Default';
if($allThemes){
	foreach ($allThemes as $theme){
		$themeData = get_option($theme);
		$themesList[$themeData['slug']] = $themeData['title'];
	}
}

/**
 * Animations
 */
$allAnimations = array();
$allAnimations['slide'] = 'Slide';
$allAnimations['pushslide'] = 'Push Slide';
$allAnimations['scale'] = 'Scale';
$allAnimations['pushscale'] = 'Push Scale';
$allAnimations['scaletl'] = 'Scale Top Left';
$allAnimations['pushscaletl'] = 'Push Scale Top Left';
$allAnimations['scaletr'] = 'Scale Top Right';
$allAnimations['pushscaletr'] = 'Push Scale Top Right';
$allAnimations['scalebl'] = 'Scale Bottom Left';
$allAnimations['pushscalebl'] = 'Push Scale Bottom Left';
$allAnimations['scalebr'] = 'Scale Bottom Right';
$allAnimations['pushscalebr'] = 'Push Scale Bottom Right';
$allAnimations['rotate'] = 'Rotate';
$allAnimations['pushrotate'] = 'Push Rotate';
$allAnimations['fadein'] = 'Fade In';
$allAnimations['pushfadein'] = 'Push Fade In';
$allAnimations['reveal'] = 'Reveal';

/**
 * Sides
 */
$wpoffcanvaspanels_sides = array('left', 'right', 'top', 'bottom');

/**
 * Add options
 */
if (!get_option('wpoffcanvaspanels_options')) {
	add_option('wpoffcanvaspanels_options', $wpoffcanvaspanels_settings);
}

/**
 * Admin scripts
 */
function wpoffcanvaspanels_admin_scripts() {
	wp_enqueue_media();
	wp_enqueue_script('wp-off-canvas-panels-admin-js', plugins_url('js/wp-off-canvas-panels-admin.js', __FILE__), array('jquery-ui-accordion'));
	wp_enqueue_style('wp-off-canvas-panels-admin-css', plugins_url('css/wp-off-canvas-panels-admin.css', __FILE__));
}

add_action('admin_enqueue_scripts', 'wpoffcanvaspanels_admin_scripts');

/**
 * Add settings page
 */
function wpoffcanvaspanels_admin_menu() {
	add_options_page(__('WP Off Canvas Panels', 'wpoffcanvaspanels'), __('WP Off Canvas Panels', 'wpoffcanvaspanels'), 'manage_options', 'wp-off-canvas-panels', 'wpoffcanvaspanels_admin_page');
}

add_action('admin_menu', 'wpoffcanvaspanels_admin_menu');

/**
 * Settings page
 */
function wpoffcanvaspanels_admin_page() {
	$tab = isset($_GET['tab']) ? $_GET['tab'] : 'settings';
	?>
	<div class="wrap">
		<h2>WP Off Canvas Panels</h2>
		<?php
		wpoffcanvaspanels_admin_tabs($tab);
		switch ($tab) {
			case 'settings':
				wpoffcanvaspanels_admin_page_settings();
				break;
			case 'styles':
				wpoffcanvaspanels_admin_page_styles();
				break;
		}
		?>
	</div>
	<?php
}

/**
 * Tab menu
 */
function wpoffcanvaspanels_admin_tabs($current) {
	$tabs = array('settings' => 'Settings', 'styles' => 'Styles');
	echo '<h2 class="nav-tab-wrapper">';
	foreach ($tabs as $tab => $name) {
		$class = ( $tab == $current ) ? ' nav-tab-active' : '';
		echo "<a class='nav-tab$class' href='?page=wp-off-canvas-panels&tab=$tab'>$name</a>";
	}
	echo '</h2>';
}

/**
 * Styles page content
 */
function wpoffcanvaspanels_admin_page_styles() {
	wpoffcanvaspanels_styletool_page();
}

/**
 * Settings page content
 */
function wpoffcanvaspanels_admin_page_settings() {
	?>
	<form method="post" action="options.php" enctype="multipart/form-data">
		<div id="wpoffcanvaspanels_settings">
			<?php
			settings_fields('wpoffcanvaspanels_options');
			do_settings_sections('wpoffcanvaspanels');
			?></div><?php
		submit_button();
			?>
	</form>
	<?php
}

/**
 * Admin init
 */
function wpoffcanvaspanels_admin_init() {
	register_setting('wpoffcanvaspanels_options', 'wpoffcanvaspanels_options', 'wpoffcanvaspanels_options_save');
	global $wpoffcanvaspanels_sides;
	foreach ($wpoffcanvaspanels_sides as $side) {
		$args = array('side' => $side);
		$section = 'wpoffcanvaspanels_' . $side;
		add_settings_section($section, $side . ' settings', 'wpoffcanvaspanels_empty', 'wpoffcanvaspanels');
		add_settings_field('wpoffcanvaspanels_enable', 'Enabled', 'wpoffcanvaspanels_enable', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_size', 'Size', 'wpoffcanvaspanels_size', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_add_close_button', 'Add close button', 'wpoffcanvaspanels_add_close_button', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_show_when_near', 'Show when near', 'wpoffcanvaspanels_show_when_near', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_add_button', 'Add button', 'wpoffcanvaspanels_add_button', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_button_text', 'Button text', 'wpoffcanvaspanels_button_text', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_button_image', 'Button image', 'wpoffcanvaspanels_button_image', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_button_position', 'Button position', 'wpoffcanvaspanels_button_position', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_animation', 'Animation', 'wpoffcanvaspanels_animation', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_overlay', 'Overlay', 'wpoffcanvaspanels_overlay', 'wpoffcanvaspanels', $section, $args);
		add_settings_field('wpoffcanvaspanels_style', 'Style', 'wpoffcanvaspanels_style', 'wpoffcanvaspanels', $section, $args);
	}
}

add_action('admin_init', 'wpoffcanvaspanels_admin_init');

function wpoffcanvaspanels_empty(){
	
}

/**
 * Enable field
 */
function wpoffcanvaspanels_enable($args) {
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_enabled_' . $side;
	$settingName = 'enabled_' . $side;
	?>
	<label for="<?php echo $fieldID; ?>">
		<input name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]" type="checkbox" id="<?php echo $fieldID; ?>" value="1" <?php
	if ($options[$settingName])
		echo 'checked="checked"';
	?>>
		Enabled
	</label>
	<p class="description">Enable or disable this panel.</p>
	<?php
}

/**
 * Size field
 */
function wpoffcanvaspanels_size($args) {
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_size_' . $side;
	$typeFieldID = 'wpoffcanvaspanels_size_type_' . $side;
	$settingName = 'size_' . $side;
	$typeSettingName = 'size_type_' . $side;
	?>
	<input class="small-text" type="number" id="<?php echo $fieldID; ?>" name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]" value="<?php echo $options[$settingName]; ?>" step="1" min="1" />
	<select id="<?php echo $typeFieldID; ?>" name="wpoffcanvaspanels_options[<?php echo $typeSettingName; ?>]">
		<option value="px" <?php if ($options[$typeSettingName] == 'px')echo 'selected="selected"';?>>Pixels</option>
		<option value="%" <?php if ($options[$typeSettingName] == '%')echo 'selected="selected"';?>>Percentage</option>
	</select>
	<p class="description">Panel size, this is used as width for the left and right panel and as height for the top and bottom panel.</p>
	<?php
}

/**
 * Add close button field
 */
function wpoffcanvaspanels_add_close_button($args) {
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_add_close_button_' . $side;
	$settingName = 'add_close_button_' . $side;
	?>
	<label for="<?php echo $fieldID; ?>">
		<input name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]" type="checkbox" id="<?php echo $fieldID; ?>" value="1" <?php
	if ($options[$settingName])
		echo 'checked="checked"';
	?>>
		Add close button
	</label>
	<p class="description">Add a close button to the panel.</p>
	<?php
}

/**
 * Show when near field
 */
function wpoffcanvaspanels_show_when_near($args) {
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_show_when_near_' . $side;
	$settingName = 'show_when_near_' . $side;
	?>
	<label for="<?php echo $fieldID; ?>">
		<input name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]" type="checkbox" id="<?php echo $fieldID; ?>" value="1" <?php
	if ($options[$settingName])
		echo 'checked="checked"';
	?>>
		Show when near
	</label>
	<p class="description">When enabled the panel will show when the user is close with the mouse (disabled for mobile)</p>
	<?php
}

/**
 * Add button field
 */
function wpoffcanvaspanels_add_button($args) {
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_add_button_' . $side;
	$settingName = 'add_button_' . $side;
	?>
	<label for="<?php echo $fieldID; ?>">
		<input name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]" type="checkbox" id="<?php echo $fieldID; ?>" value="1" <?php
	if ($options[$settingName])
		echo 'checked="checked"';
	?>>
		Add button
	</label>
	<p class="description">When enabled a button is added to open the panel.</p>
	<p class="description">It is also possible to make a link or menu item to open this panel to do this you must make sure the link is: "#wp-off-canvas-panels-<?php echo $side; ?>"</p>
	<?php
}

/**
 * Button text field
 */
function wpoffcanvaspanels_button_text($args) {
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_button_text_' . $side;
	$settingName = 'button_text_' . $side;
	?>
	<input type="text" id="<?php echo $fieldID; ?>" name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]" value="<?php echo $options[$settingName]; ?>" />
	<p class="description">Text for the button.</p>
	<?php
}

/**
 * Button image field
 */
function wpoffcanvaspanels_button_image($args) {
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_button_image_' . $side;
	$settingName = 'button_image_' . $side;
	?>
	<input id="<?php echo $fieldID; ?>" type="text" size="36" name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]" value="<?php echo $options[$settingName]; ?>" />
	<input id="<?php echo $fieldID; ?>_button" class="button" type="button" value="Upload Image" />
	<p class="description">Image for the button.</p>
	<?php
}

/**
 * Button position field
 */
function wpoffcanvaspanels_button_position($args) {
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_button_position_' . $side;
	$settingName = 'button_position_' . $side;
	?>
	<select id="<?php echo $fieldID; ?>" name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]">
		<option value="top-left" <?php
	if ($options[$settingName] == 'top-left')
		echo 'selected="selected"';
	?>>Top left</option>
		<option value="center-left" <?php
			if ($options[$settingName] == 'center-left')
				echo 'selected="selected"';
	?>>Center left</option>
		<option value="bottom-left" <?php
			if ($options[$settingName] == 'bottom-left')
				echo 'selected="selected"';
	?>>Bottom left</option>
		<option value="top-right" <?php
			if ($options[$settingName] == 'top-right')
				echo 'selected="selected"';
	?>>Top Right</option>
		<option value="center-right" <?php
			if ($options[$settingName] == 'center-right')
				echo 'selected="selected"';
	?>>Center right</option>
		<option value="bottom-right" <?php
			if ($options[$settingName] == 'bottom-right')
				echo 'selected="selected"';
	?>>Bottom right</option>
		<option value="top-center" <?php
			if ($options[$settingName] == 'top-center')
				echo 'selected="selected"';
	?>>Top center</option>
		<option value="bottom-center" <?php
			if ($options[$settingName] == 'bottom-center')
				echo 'selected="selected"';
	?>>Bottom center</option>
	</select>
	<p class="description">Button position.</p>
	<?php
}

/**
 * Animation field
 */
function wpoffcanvaspanels_animation($args) {
	global $allAnimations;
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_animation_' . $side;
	$settingName = 'animation_' . $side;
	?>
	<select id="<?php echo $fieldID; ?>" name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]">
		<?php foreach($allAnimations as $slug => $title){
			if($slug == $options[$settingName]){
				echo '<option value="'.$slug.'" selected="selected">'.$title.'</option>';
			}else{
				echo '<option value="'.$slug.'">'.$title.'</option>';
			}
		}?>
	</select>
	<p class="description">Panel animation.</p>
	<?php
}

/**
 * Overlay field
 */
function wpoffcanvaspanels_overlay($args) {
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_overlay_' . $side;
	$settingName = 'overlay_' . $side;
	?>
	<label for="<?php echo $fieldID; ?>">
		<input name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]" type="checkbox" id="<?php echo $fieldID; ?>" value="1" <?php
	if ($options[$settingName])
		echo 'checked="checked"';
	?>>
		Display overlay when menu is open
	</label>
	<p class="description">If check an overlay will be added when the panel is shown.</p>
	<?php
}

/**
 * Style field
 */
function wpoffcanvaspanels_style($args) {
	global $themesList;
	$options = get_option('wpoffcanvaspanels_options');
	$side = $args['side'];
	$fieldID = 'wpoffcanvaspanels_style_' . $side;
	$settingName = 'style_' . $side;
	?>
	<select id="<?php echo $fieldID; ?>" name="wpoffcanvaspanels_options[<?php echo $settingName; ?>]">
		<?php foreach($themesList as $slug => $title){
			if($slug == $options[$settingName]){
				echo '<option value="'.$slug.'" selected="selected">'.$title.'</option>';
			}else{
				echo '<option value="'.$slug.'">'.$title.'</option>';
			}
		}
		?>
	</select>
	<p class="description">Panel and button style.</p>
	<?php
}

/**
 * Save settings
 */
function wpoffcanvaspanels_options_save($input) {
	global $wpoffcanvaspanels_settings;
	global $wpoffcanvaspanels_sides;
	foreach ($wpoffcanvaspanels_sides as $side) {
		if (!isset($input['enabled_' . $side])) {
			$input['enabled_' . $side] = 0;
		}
		if (!isset($input['overlay_' . $side])) {
			$input['overlay_' . $side] = 0;
		}
		if (!isset($input['show_when_near_' . $side])) {
			$input['show_when_near_' . $side] = 0;
		}
		if (!isset($input['add_close_button_' . $side])) {
			$input['add_close_button_' . $side] = 0;
		}
		if (!isset($input['add_button_' . $side])) {
			$input['add_button_' . $side] = 0;
		}
	}
	$options = array_merge(get_option('wpoffcanvaspanels_options'), $input);
	return $options;
}