<?php

/**
 * Plugin Name: WP off canvas panels
 * Plugin URI: http://michelvandersteege.nl/envato/wp-off-canvas-panels
 * Description: Off canvas panels for wordpress
 * Version: 1.1
 * Author: Michel van der Steege
 * Author URI: http://www.michelvandersteege.nl
 * License: GPL2
 */
/*  Copyright 2014 Michel van der Steege
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/* Settings link */
function wpoffcanvaspanels_settings_link($links) {
	$settings_block = '<a href="' . admin_url('admin.php?page=wp-off-canvas-panels') . '">Settings</a>';
	array_unshift($links, $settings_block);
	return $links;
}

$plugin = plugin_basename(__FILE__);
add_filter("plugin_action_links_$plugin", 'wpoffcanvaspanels_settings_link');

/**
 * Admin
 */
if (is_admin()) {
	require dirname(__FILE__) . '/settings.php';
}

/**
 * Add widget areas
 */
function wpoffcanvaspanels_widgets_init() {
	register_sidebar(array(
		'name' => 'WP off-canvas left',
		'id' => 'wp-off-canvas-left',
		'description' => 'Off canvas left panel widgets',
		'before_widget' => '<div class="widget %2$s">',
		'after_widget' => '</div>'
	));
	register_sidebar(array(
		'name' => 'WP off-canvas right',
		'id' => 'wp-off-canvas-right',
		'description' => 'Off canvas right panel widgets',
		'before_widget' => '<div class="widget %2$s">',
		'after_widget' => '</div>'
	));
	register_sidebar(array(
		'name' => 'WP off-canvas top',
		'id' => 'wp-off-canvas-top',
		'description' => 'Off canvas top panel widgets',
		'before_widget' => '<div class="widget %2$s">',
		'after_widget' => '</div>'
	));
	register_sidebar(array(
		'name' => 'WP off-canvas bottom',
		'id' => 'wp-off-canvas-bottom',
		'description' => 'Off canvas bottom panel widgets',
		'before_widget' => '<div class="widget %2$s">',
		'after_widget' => '</div>'
	));
}

add_action('widgets_init', 'wpoffcanvaspanels_widgets_init');

/**
 * Enqueue scripts
 */
function wpoffcanvaspanels_enqueue_scripts() {
	//js
	wp_enqueue_script('jquery');
	wp_enqueue_script('wprmenu.js', plugins_url('/js/wp-off-canvas-panels.js', __FILE__), array('jquery'));

	//basic css
	wp_enqueue_style('wpoffcanvaspanels_style', plugins_url('css/wp-off-canvas-panels.css', __FILE__));

	//styles and animations
	$options = get_option('wpoffcanvaspanels_options');
	$sides = array('left', 'right', 'top', 'bottom');
	foreach ($sides as $side) {
		$styleName = $options['style_' . $side];
		$styleCss = plugins_url('css/styles/' . $styleName . '.css', __FILE__);
		$animationName = $options['animation_' . $side];
		$animationCss = plugins_url('css/animations/' . $animationName . '.css', __FILE__);
		wp_enqueue_style('wpoffcanvaspanels_' . $styleName, $styleCss);
		wp_enqueue_style('wpoffcanvaspanels_animation_' . $animationName, $animationCss);
	}
}

add_action('wp_enqueue_scripts', 'wpoffcanvaspanels_enqueue_scripts');

/**
 * Render menu
 */
function wpoffcanvaspanels_render() {
	//Vars
	$sides = array('left', 'right', 'top', 'bottom');
	$options = get_option('wpoffcanvaspanels_options');
	//Loop through sides
	foreach ($sides as $side) {
		//Check enabled
		if (!$options['enabled_' . $side]) {
			continue;
		}
		//Check sidebar
		$sidebarID = 'wp-off-canvas-' . $side;
		if (!is_active_sidebar($sidebarID)) {
			continue;
		}
		//Settings
		$showWhenNear = $options['show_when_near_' . $side] ? 'true' : 'false';
		$addCloseButton = $options['add_close_button_' . $side];
		$animation = $options['animation_' . $side];
		$animationClass = 'wpoffcanvaspanels_' . $animation;
		$styleClass = 'wpoffcanvaspanels_' . $options['style_' . $side];
		$overlay = $options['overlay_' . $side] ? 'true' : 'false';
		$positionClass = 'wpoffcanvaspanels_' . $side;
		$panelClasses = $positionClass . ' ' . $styleClass . ' ' . $animationClass;
		$size = $options['size_' . $side];
		$pxOrPerc = $options['size_type_' . $side];
		if ($side == 'left') {
			$style = 'style="width:' . $size . $pxOrPerc . ';left:-' . $size . $pxOrPerc . '"';
		} elseif ($side == 'right') {
			$style = 'style="width:' . $size . $pxOrPerc . ';right:-' . $size . $pxOrPerc . '"';
		} else if ($side == 'top') {
			$style = 'style="height:' . $size . $pxOrPerc . ';top:-' . $size . $pxOrPerc . '"';
		} else {
			$style = 'style="height:' . $size . $pxOrPerc . ';bottom:-' . $size . $pxOrPerc . '"';
		}

		//Add panel
		?>
		<div <?php echo $style; ?> class="wpoffcanvaspanels_panel <?php echo $panelClasses; ?>" data-side="<?php echo $side; ?>" data-showwhennear="<?php echo $showWhenNear; ?>" data-overlay="<?php echo $overlay; ?>" data-animation="<?php echo $animation; ?>">
			<div>
				<?php if ($addCloseButton): ?><span class="wpoffcanvaspanels_close">x</span><?php endif; ?>
				<?php dynamic_sidebar($sidebarID); ?>
			</div>
		</div>
		<?php
		//Buttons
		if ($options['add_button_' . $side]) {
			//Button settings
			$buttonText = $options['button_text_' . $side];
			$buttonImage = $options['button_image_' . $side];
			$buttonPosition = 'wpoffcanvaspanels_' . $options['button_position_' . $side];
			//Add button
			?>
			<div class="wpoffcanvaspanels_button <?php echo $buttonPosition . ' ' . $styleClass; ?>" data-target="<?php echo $positionClass; ?>">
				<?php if($buttonImage && $buttonText):?>
					<span><img src="<?php echo $buttonImage; ?>" /> <?php echo $buttonText; ?></span>
				<?php else:  ?>
					<?php if ($buttonImage): ?><img src="<?php echo $buttonImage; ?>" /><?php endif; ?>
					<?php if ($buttonText): echo '<span>' . $buttonText . '</span>'; endif; ?>
				<?php endif;  ?>
			</div>
			<?php
		}
	}
	?>
	<div id="wpoffcanvaspanels_overlay"></div>
	<?php
}

add_action('wp_footer', 'wpoffcanvaspanels_render', 100);

/**
 * Activation
 */
function wpoffcanvaspanels_activate() {
    wpoffcanvaspanels_install_default_themes();
}
register_activation_hook(__FILE__, 'wpoffcanvaspanels_activate');