<?php
$style_tool_prefix = 'wpoffcanvaspanels_styletool_';
function getStyleToolPrefix(){
	return 'wpoffcanvaspanels_styletool_';
}

/**
 * Slugify
 */
function styletool_slugify($text) {
	$text = preg_replace('~[^\\pL\d]+~u', '-', $text);
	$text = trim($text, '-');
	if (function_exists('iconv')) {
		$text = iconv('utf-8', 'us-ascii//TRANSLIT', $text);
	}
	$text = strtolower($text);
	$text = preg_replace('~[^-\w]+~', '', $text);
	if (empty($text)) {
		return 'n-a';
	}
	return $text;
}

/**
 * Styletool scripts
 */
function wpoffcanvaspanels_styletool_admin_scripts() {
	wp_enqueue_script('wp-color-picker');
	
	wp_enqueue_script('spectrum', plugins_url('classygradient/js/spectrum.js', __FILE__), array('jquery'));
	wp_enqueue_style('spectrum', plugins_url('classygradient/css/spectrum.css', __FILE__));
	
	wp_enqueue_script('classygradient', plugins_url('classygradient/js/jquery.classygradient.js', __FILE__), array('jquery'));
	wp_enqueue_style('classygradient', plugins_url('classygradient/css/jquery.classygradient.css', __FILE__));
	wp_enqueue_script('wp-styletool', plugins_url('wp-styletool.js', __FILE__), array('jquery'));
	wp_enqueue_style('wp-styletool', plugins_url('wp-styletool.css', __FILE__));
}

add_action('admin_enqueue_scripts', 'wpoffcanvaspanels_styletool_admin_scripts');

/**
 * Add new theme option
 */
function wpoffcanvaspanels_styletool_add_theme_option($themeSlug) {
	$style_tool_prefix = getStyleToolPrefix();
	$allThemesOptionName = $style_tool_prefix . 'all_themes';
	$allThemes = get_option($allThemesOptionName);
	if ($allThemes === FALSE) {
		$allThemes = array($themeSlug);
		add_option($allThemesOptionName, $allThemes);
	} else {
		$allThemes[] = $themeSlug;
		update_option($allThemesOptionName, $allThemes);
	}
}

/**
 * Remove theme option
 */
function wpoffcanvaspanels_styletool_remove_theme_option($themeSlug) {
	$style_tool_prefix = getStyleToolPrefix();
	$allThemesOptionName = $style_tool_prefix . 'all_themes';
	$allThemes = get_option($allThemesOptionName);
	if ($allThemes !== FALSE) {
		unset($allThemes[array_search($themeSlug, $allThemes)]);
		update_option($allThemesOptionName, $allThemes);
	}
}

/**
 * Add new theme ajax function
 */
function wpoffcanvaspanels_styletool_add_new_theme() {
	if (!isset($_POST['theme_title'])) {
		$output = array(
			'error' => true,
			'message' => 'No theme title?'
		);
	} else {
		$themeTitle = $_POST['theme_title'];
		if ($themeTitle == '') {
			$output = array(
				'error' => true,
				'message' => 'The theme title is required.'
			);
		} else {
			$themeSlug = styletool_slugify($themeTitle);
			$reservedSlugs = array('all_themes', 'default');
			if (in_array($themeSlug, $reservedSlugs)) {
				$output = array(
					'error' => true,
					'message' => 'This theme title is reserved.'
				);
			} else {
				$style_tool_prefix = getStyleToolPrefix();
				$themeSettingName = $style_tool_prefix . $themeSlug;
				if (get_option($themeSettingName)) {
					$output = array(
						'error' => true,
						'message' => 'This theme already exists.'
					);
				} else {
					add_option($themeSettingName, array(
						'title' => $themeTitle,
						'slug' => $themeSlug
					));
					wpoffcanvaspanels_styletool_add_theme_option($themeSettingName);
					$stylesFolder = dirname(dirname(__FILE__)) . '/css/styles/';
					@chmod($stylesFolder, 0755);
					if(!is_writable($stylesFolder)) {
						$output = array(
							'error' => true,
							'message' => 'The plugin folder is not writable.'
						);
					}else{
						$toCopyCssURL = dirname(dirname(__FILE__)) . '/css/styles/default.css';
						$newThemeCssURL = dirname(dirname(__FILE__)) . '/css/styles/' . $themeSlug . '.css';
						$toCopyCss = file_get_contents($toCopyCssURL);
						$newThemeCss = str_replace('_default', '_' . $themeSlug, $toCopyCss);
						file_put_contents($newThemeCssURL, $newThemeCss);
						$output = array(
							'error' => false,
							'message' => 'Theme added!'
						);
					}
				}
			}
		}
	}
	echo json_encode($output);
	die();
}

add_action('wp_ajax_wpoffcanvaspanels_styletool_add_new_theme', 'wpoffcanvaspanels_styletool_add_new_theme');

/**
 * Copy theme ajax function
 */
function wpoffcanvaspanels_styletool_copy_theme() {
	if (!isset($_POST['theme_slug'])) {
		$output = array(
			'error' => true,
			'message' => 'No theme slug?'
		);
	} elseif (!isset($_POST['new_theme_title'])) {
		$output = array(
			'error' => true,
			'message' => 'No new theme title?'
		);
	} else {
		$themeSlug = $_POST['theme_slug'];
		$style_tool_prefix = getStyleToolPrefix();
		$themeSettingName = $style_tool_prefix . $themeSlug;
		$themeData = get_option($themeSettingName);
		if (!$themeData) {
			$output = array(
				'error' => true,
				'message' => 'This theme does not exists.'
			);
		} else {
			$newThemeTitle = $_POST['new_theme_title'];
			if ($newThemeTitle == '') {
				$output = array(
					'error' => true,
					'message' => 'The theme title is required.'
				);
			} else {
				$newThemeSlug = styletool_slugify($newThemeTitle);
				$newThemeSettingName = $style_tool_prefix . $newThemeSlug;
				if (get_option($newThemeSettingName)) {
					$output = array(
						'error' => true,
						'message' => 'This theme already exists.'
					);
				} else {
					add_option($newThemeSettingName, array(
						'title' => $newThemeTitle,
						'slug' => $newThemeSlug,
						'data' => $themeData['data']
					));
					wpoffcanvaspanels_styletool_add_theme_option($newThemeSettingName);
					$stylesFolder = dirname(dirname(__FILE__)) . '/css/styles/';
					@chmod($stylesFolder, 0755);
					if(!is_writable($stylesFolder)) {
						$output = array(
							'error' => true,
							'message' => 'The plugin folder is not writable.'
						);
					}else{
						$toCopyCssURL = dirname(dirname(__FILE__)) . '/css/styles/' . $themeSlug . '.css';
						$newThemeCssURL = dirname(dirname(__FILE__)) . '/css/styles/' . $newThemeSlug . '.css';
						$toCopyCss = file_get_contents($toCopyCssURL);
						$newThemeCss = str_replace('_' . $themeSlug, '_' . $newThemeSlug, $toCopyCss);
						file_put_contents($newThemeCssURL, $newThemeCss);
						$output = array(
							'error' => false,
							'message' => 'Theme copied!'
						);
					}
				}
			}
		}
	}
	echo json_encode($output);
	die();
}

add_action('wp_ajax_wpoffcanvaspanels_styletool_copy_theme', 'wpoffcanvaspanels_styletool_copy_theme');

/**
 * Remove theme ajax function
 */
function wpoffcanvaspanels_styletool_remove_theme() {
	if (!isset($_POST['theme_slug'])) {
		$output = array(
			'error' => true,
			'message' => 'No theme slug?'
		);
	} else {
		$themeSlug = $_POST['theme_slug'];
		$style_tool_prefix = getStyleToolPrefix();
		$themeSettingName = $style_tool_prefix . $themeSlug;
		if (!get_option($themeSettingName)) {
			$output = array(
				'error' => true,
				'message' => 'This theme does not exists.'
			);
		} else {
			$cssURL = dirname(dirname(__FILE__)) . '/css/styles/' . $themeSlug . '.css';
			if (file_exists($cssURL)) {
				unlink($cssURL);
			}
			delete_option($themeSettingName);
			wpoffcanvaspanels_styletool_remove_theme_option($themeSettingName);
			$output = array(
				'error' => false,
				'message' => 'Theme removed!'
			);
		}
	}
	echo json_encode($output);
	die();
}

add_action('wp_ajax_wpoffcanvaspanels_styletool_remove_theme', 'wpoffcanvaspanels_styletool_remove_theme');

/**
 * Save theme ajax function
 * 
 */
function wpoffcanvaspanels_styletool_save_theme() {
	if (!isset($_POST['theme_slug'])) {
		$output = array(
			'error' => true,
			'message' => 'No theme slug?'
		);
	} else if (!isset($_POST['theme_css'])) {
		$output = array(
			'error' => true,
			'message' => 'No theme css?'
		);
	} else if (!isset($_POST['theme_data'])) {
		$output = array(
			'error' => true,
			'message' => 'No theme data?'
		);
	} else {
		$themeSlug = $_POST['theme_slug'];
		$themeCss = $_POST['theme_css'];
		$themeData = $_POST['theme_data'];
		$style_tool_prefix = getStyleToolPrefix();
		$themeSettingName = $style_tool_prefix . $themeSlug;
		$themeSavedData = get_option($themeSettingName);
		if (!$themeSavedData) {
			$output = array(
				'error' => true,
				'message' => 'This theme does not exists.'
			);
		} else {
			$themeSavedData['data'] = $themeData;
			$stylesFolder = dirname(dirname(__FILE__)) . '/css/styles/';
			@chmod($stylesFolder, 0755);
			if(!is_writable($stylesFolder)) {
				$output = array(
					'error' => true,
					'message' => 'The plugin folder is not writable.'
				);
			}else{
				$cssURL = dirname(dirname(__FILE__)) . '/css/styles/' . $themeSlug . '.css';
				file_put_contents($cssURL, $themeCss);
				update_option($themeSettingName, $themeSavedData);
				$output = array(
					'error' => false,
					'message' => 'Theme saved!'
				);
			}
		}
	}
	echo json_encode($output);
	die();
}

add_action('wp_ajax_wpoffcanvaspanels_styletool_save_theme', 'wpoffcanvaspanels_styletool_save_theme');

/**
 * Get a theme ajax function
 */
function wpoffcanvaspanels_styletool_get_theme() {
	if (!isset($_POST['theme_slug'])) {
		$output = array(
			'error' => true,
			'message' => 'No theme slug?'
		);
	} else {
		$themeSlug = $_POST['theme_slug'];
		$style_tool_prefix = getStyleToolPrefix();
		$themeSettingName = $style_tool_prefix . $themeSlug;
		$themeData = get_option($themeSettingName);
		if (!$themeData) {
			$output = array(
				'error' => true,
				'message' => 'This theme does not exists.'
			);
		} else {
			$output = $themeData;
		}
	}
	echo json_encode($output);
	die();
}

add_action('wp_ajax_wpoffcanvaspanels_styletool_get_theme', 'wpoffcanvaspanels_styletool_get_theme');

/**
 * Get a theme ajax function
 */
function wpoffcanvaspanels_styletool_export_theme() {
	if (!isset($_POST['theme_slug'])) {
		$output = array(
			'error' => true,
			'message' => 'No theme slug?'
		);
	} else {
		$themeSlug = $_POST['theme_slug'];
		$style_tool_prefix = getStyleToolPrefix();
		$themeSettingName = $style_tool_prefix . $themeSlug;
		$themeData = get_option($themeSettingName);
		if (!$themeData) {
			$output = array(
				'error' => true,
				'message' => 'This theme does not exists.'
			);
		} else {
			$themeCss = dirname(dirname(__FILE__)) . '/css/styles/' . $themeSlug . '.css';
			$themeCssContent = file_get_contents($themeCss);
			$output = array(
				'error' => false,
				'data' => maybe_serialize($themeData),
				'css' => base64_encode($themeCssContent),
				'link' => plugins_url('exportstyle.php', __FILE__)
			);
		}
	}
	echo json_encode($output);
	die();
}

add_action('wp_ajax_wpoffcanvaspanels_styletool_export_theme', 'wpoffcanvaspanels_styletool_export_theme');

/**
 * Table body
 */
function wpoffcanvaspanels_styletool_table_body() {
	$style_tool_prefix = getStyleToolPrefix();
	$allThemesOptionName = $style_tool_prefix . 'all_themes';
	$allThemes = get_option($allThemesOptionName);
	if(!$allThemes){
		$allThemes = array();
	}
	$count = 0;
	foreach ($allThemes as $theme):
		$themeData = get_option($theme);
		if (!$themeData) {
			continue;
		}
		$count++;
		$class = '';
		if ($count % 2 != 0) {
			$class = 'alternate';
		}
		?>
		<tr data-slug="<?php echo $themeData['slug']; ?>" class="<?php echo $class; ?>">
			<td><?php echo $themeData['title']; ?></td>
			<td>
				<a class="edit-button" style="margin-right:10px;" href="#"><img style="vertical-align: middle;" src="<?php echo plugins_url('img/edit-icon.png', __FILE__); ?>" /> Edit</a>
				<a class="copy-button" style="margin-right:10px;" href="#"><img style="vertical-align: middle;" src="<?php echo plugins_url('img/copy-icon.png', __FILE__); ?>" /> Copy</a>
				<a class="delete-button" style="margin-right:10px;" href="#"><img style="vertical-align: middle;" src="<?php echo plugins_url('img/delete-icon.png', __FILE__); ?>" /> Delete</a>
				<a class="export-button" href="#"><img style="vertical-align: middle;" src="<?php echo plugins_url('img/export-icon.png', __FILE__); ?>" /> Export</a>
			</td>
		</tr>
		<?php
	endforeach;
}

/**
 * Import
 */
function wpoffcanvaspanels_check_import(){
	if(!isset($_FILES['importfile'])){
		return '';
	}
	$importfile = $_FILES['importfile'];
	if(substr($importfile['name'], -4) != 'wpse'){
		return '<div class="error settings-error"><p><strong>This is not a valid style editor file.</strong></p></div>';
	}
	$importfileContent = file_get_contents($importfile['tmp_name']);
	$importfileArray = explode("\n", $importfileContent);
	$importfilePlugin = $importfileArray[0];
	$importfileVersion = $importfileArray[1];
	if($importfilePlugin != 'wp-off-canvas-panels' || $importfileVersion != '1.0'){
		return '<div class="error settings-error"><p><strong>This style file is not for this plugin.</strong></p></div>';
	}
	$importfileData = maybe_unserialize($importfileArray[3]);
	$importfileCss = base64_decode($importfileArray[7]);
	if(isset($_POST['importtitle']) && !empty($_POST['importtitle'])){
		$importtitle = $_POST['importtitle'];
		$importslug = styletool_slugify($importtitle);
		$oldslug = $importfileData['slug'];
		$importfileData['title'] = $importtitle;
		$importfileData['slug'] = $importslug;
		$importfileCss = str_replace('_' . $oldslug, '_' . $importslug, $importfileCss);
	}
	$style_tool_prefix = getStyleToolPrefix();
	$styleOptionName = $style_tool_prefix . $importfileData['slug'];
	if(get_option($styleOptionName)){
		return '<div class="error settings-error"><p><strong>There is already a style named: '.$importfileData["title"].'</strong></p></div>';
	}
	$stylesFolder = dirname(dirname(__FILE__)) . '/css/styles/';
	@chmod($stylesFolder, 0755);
	if(!is_writable($stylesFolder)) {
		return '<div class="error settings-error"><p><strong>The plugin folder is not writable!</strong></p></div>';
	}
	add_option($styleOptionName, $importfileData);
	wpoffcanvaspanels_styletool_add_theme_option($styleOptionName);
	$cssURL = $stylesFolder . $importfileData['slug'] . '.css';
	file_put_contents($cssURL, $importfileCss);
	return '<div class="updated settings-error"><p><strong>Imported successful!</strong></p></div>';
}

/**
 * Styletool page
 */
function wpoffcanvaspanels_styletool_page() {
	$import = wpoffcanvaspanels_check_import();
	?>
	<script>var styletoolPluginURL = '<?php echo plugins_url('/', __FILE__); ?>';</script>
	<div class="tablenav top" style="margin-top:20px;">
		<a href="#" id="style-tool-new-theme" class="button action">New theme</a>
	</div>
	<table id="style-tool-table" class="wp-list-table widefat fixed posts">
		<thead>
			<tr>
				<th>Title</th>
				<th>Actions</th>
			</tr>
		</thead>
		<tbody>
			<?php wpoffcanvaspanels_styletool_table_body(); ?>
		</tbody>
	</table>
	<hr />
	<h2>Import</h2>
	<?php echo $import; ?>
	<form method="POST" enctype="multipart/form-data" action="options-general.php?page=wp-off-canvas-panels&tab=styles">
		<label style="width:140px; display: inline-block;">Import file (.wpse file)</label><input type="file" name="importfile" /><br />
		<label style="width:140px; display: inline-block;">Import style title</label><input type="text" name="importtitle" /><br />
		<p class="description">Optional change the title of the imported style</p><br />
		<input type="submit" value="Import" class="button" />
	</form>
	<div id="style-tool-modal" style="display: none;">
		<div class="media-modal wp-core-ui">
			<a title="Close" href="#" class="media-modal-close"><span class="media-modal-icon"></span></a>
			<div class="media-modal-content">
				<div class="media-frame wp-core-ui hide-menu">
					<div class="media-frame-title">
						<h1>Style editor</h1>
					</div>
					<div class="media-frame-content" style="top:60px; padding:10px; background: #E1E1E1;"></div>
					<div class="media-frame-toolbar">
						<div class="media-toolbar">
							<div class="media-toolbar-primary">
								<a href="#" class="button media-button button-primary button-large save-button">Save</a>
								<a href="#" class="button media-button button-primary button-large save-close-button">Save and close</a>
								<a href="#" class="button media-button button-primary button-large cancel-button">Cancel</a>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<div class="media-modal-backdrop"></div>
	</div>
	<div id="wp-styletool-loader"><img src="<?php echo plugins_url('img/loader.gif', __FILE__); ?>" /></div>
	<?php
}

/**
 * Instal default themes
 */
function wpoffcanvaspanels_install_default_themes() {
	$style_tool_prefix = getStyleToolPrefix();
	
	//Black & White Bottom	
	$blackWhiteBottomName = $style_tool_prefix . 'black-white-bottom';
	if (!get_option($blackWhiteBottomName)) {
		$blackWhiteBottomData = 'a:3:{s:5:"title";s:20:"Black & White Bottom";s:4:"slug";s:18:"black-white-bottom";s:4:"data";a:15:{s:5:"panel";a:6:{s:5:"color";s:7:"#000000";s:6:"shadow";s:29:"0px 4px 5px 0px #adadad inset";s:10:"background";s:20:"vertical, 0% #FFFFFF";s:7:"padding";s:19:"10px 10px 10px 10px";s:6:"border";s:0:"";s:10:"text-align";s:0:"";}s:5:"links";a:5:{s:5:"color";s:7:"#000000";s:15:"text-decoration";s:9:"underline";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:11:"links-hover";a:5:{s:5:"color";s:0:"";s:15:"text-decoration";s:4:"none";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:8:"headings";a:7:{s:5:"color";s:7:"#000000";s:14:"text-transform";s:9:"uppercase";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";s:6:"border";s:0:"";s:10:"text-align";s:0:"";s:6:"margin";s:16:"15px 0px 5px 0px";}s:7:"widgets";a:5:{s:10:"background";s:0:"";s:6:"border";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:5:"color";s:0:"";}s:11:"form-labels";a:6:{s:5:"color";s:7:"#000000";s:15:"text-decoration";s:0:"";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";}s:11:"form-inputs";a:9:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:0:"";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:15:"0px 0px 0px 0px";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:17:"form-inputs-focus";a:5:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"form-buttons";a:9:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:15:"5px 5px 5px 5px";s:6:"shadow";s:23:"1px 1px 2px 0px #969696";s:7:"padding";s:17:"3px 10px 3px 10px";s:6:"margin";s:16:"10px 0px 0px 0px";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"form-buttons-hover";a:5:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:13:"toggle-button";a:9:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:19:"toggle-button-hover";a:5:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"close-button";a:9:{s:10:"background";s:22:"horizontal, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"close-button-hover";a:5:{s:10:"background";s:20:"vertical, 0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:4:"misc";a:1:{s:6:"custom";s:0:"";}}}';
		add_option($blackWhiteBottomName, maybe_unserialize($blackWhiteBottomData));
		wpoffcanvaspanels_styletool_add_theme_option($blackWhiteBottomName);
	}

	//Black & White Left
	$blackWhiteLeftName = $style_tool_prefix . 'black-white-left';
	if (!get_option($blackWhiteLeftName)) {
		$blackWhiteLeftData = 'a:3:{s:5:"title";s:18:"Black & White Left";s:4:"slug";s:16:"black-white-left";s:4:"data";a:15:{s:5:"panel";a:6:{s:5:"color";s:7:"#000000";s:6:"shadow";s:30:"-4px 0px 5px 0px #adadad inset";s:10:"background";s:20:"vertical, 0% #FFFFFF";s:7:"padding";s:19:"10px 10px 10px 10px";s:6:"border";s:0:"";s:10:"text-align";s:0:"";}s:5:"links";a:5:{s:5:"color";s:7:"#000000";s:15:"text-decoration";s:9:"underline";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:11:"links-hover";a:5:{s:5:"color";s:0:"";s:15:"text-decoration";s:4:"none";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:8:"headings";a:7:{s:5:"color";s:7:"#000000";s:14:"text-transform";s:9:"uppercase";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";s:6:"border";s:0:"";s:10:"text-align";s:0:"";s:6:"margin";s:16:"15px 0px 5px 0px";}s:7:"widgets";a:5:{s:10:"background";s:0:"";s:6:"border";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:5:"color";s:0:"";}s:11:"form-labels";a:6:{s:5:"color";s:7:"#000000";s:15:"text-decoration";s:0:"";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";}s:11:"form-inputs";a:9:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:0:"";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:15:"0px 0px 0px 0px";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:17:"form-inputs-focus";a:5:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"form-buttons";a:9:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:15:"5px 5px 5px 5px";s:6:"shadow";s:23:"1px 1px 2px 0px #969696";s:7:"padding";s:17:"3px 10px 3px 10px";s:6:"margin";s:16:"10px 0px 0px 0px";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"form-buttons-hover";a:5:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:13:"toggle-button";a:9:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:19:"toggle-button-hover";a:5:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"close-button";a:9:{s:10:"background";s:22:"horizontal, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"close-button-hover";a:5:{s:10:"background";s:20:"vertical, 0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:4:"misc";a:1:{s:6:"custom";s:0:"";}}}';
		add_option($blackWhiteLeftName, maybe_unserialize($blackWhiteLeftData));
		wpoffcanvaspanels_styletool_add_theme_option($blackWhiteLeftName);
	}

	//Black & White Right
	$blackWhiteRightName = $style_tool_prefix . 'black-white-right';
	if (!get_option($blackWhiteRightName)) {
		$blackWhiteRightData = 'a:3:{s:5:"title";s:19:"Black & White Right";s:4:"slug";s:17:"black-white-right";s:4:"data";a:15:{s:5:"panel";a:6:{s:5:"color";s:7:"#000000";s:6:"shadow";s:29:"4px 0px 5px 0px #adadad inset";s:10:"background";s:20:"vertical, 0% #FFFFFF";s:7:"padding";s:19:"10px 10px 10px 10px";s:6:"border";s:0:"";s:10:"text-align";s:0:"";}s:5:"links";a:5:{s:5:"color";s:7:"#000000";s:15:"text-decoration";s:9:"underline";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:11:"links-hover";a:5:{s:5:"color";s:0:"";s:15:"text-decoration";s:4:"none";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:8:"headings";a:7:{s:5:"color";s:7:"#000000";s:14:"text-transform";s:9:"uppercase";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";s:6:"border";s:0:"";s:10:"text-align";s:0:"";s:6:"margin";s:16:"15px 0px 5px 0px";}s:7:"widgets";a:5:{s:10:"background";s:0:"";s:6:"border";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:5:"color";s:0:"";}s:11:"form-labels";a:6:{s:5:"color";s:7:"#000000";s:15:"text-decoration";s:0:"";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";}s:11:"form-inputs";a:9:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:0:"";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:15:"0px 0px 0px 0px";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:17:"form-inputs-focus";a:5:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"form-buttons";a:9:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:15:"5px 5px 5px 5px";s:6:"shadow";s:23:"1px 1px 2px 0px #969696";s:7:"padding";s:17:"3px 10px 3px 10px";s:6:"margin";s:16:"10px 0px 0px 0px";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"form-buttons-hover";a:5:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:13:"toggle-button";a:9:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:19:"toggle-button-hover";a:5:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"close-button";a:9:{s:10:"background";s:22:"horizontal, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"close-button-hover";a:5:{s:10:"background";s:20:"vertical, 0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:4:"misc";a:1:{s:6:"custom";s:0:"";}}}';
		add_option($blackWhiteRightName, maybe_unserialize($blackWhiteRightData));
		wpoffcanvaspanels_styletool_add_theme_option($blackWhiteRightName);
	}

	//Black & White Top
	$blackWhiteTopName = $style_tool_prefix . 'black-white-top';
	if (!get_option($blackWhiteTopName)) {
		$blackWhiteTopData = 'a:3:{s:5:"title";s:17:"Black & White Top";s:4:"slug";s:15:"black-white-top";s:4:"data";a:15:{s:5:"panel";a:6:{s:5:"color";s:7:"#000000";s:6:"shadow";s:30:"0px -4px 5px 0px #adadad inset";s:10:"background";s:20:"vertical, 0% #FFFFFF";s:7:"padding";s:19:"10px 10px 10px 10px";s:6:"border";s:0:"";s:10:"text-align";s:0:"";}s:5:"links";a:5:{s:5:"color";s:7:"#000000";s:15:"text-decoration";s:9:"underline";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:11:"links-hover";a:5:{s:5:"color";s:0:"";s:15:"text-decoration";s:4:"none";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:8:"headings";a:7:{s:5:"color";s:7:"#000000";s:14:"text-transform";s:9:"uppercase";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";s:6:"border";s:0:"";s:10:"text-align";s:0:"";s:6:"margin";s:16:"15px 0px 5px 0px";}s:7:"widgets";a:5:{s:10:"background";s:0:"";s:6:"border";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:5:"color";s:0:"";}s:11:"form-labels";a:6:{s:5:"color";s:7:"#000000";s:15:"text-decoration";s:0:"";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";}s:11:"form-inputs";a:9:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:0:"";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:15:"0px 0px 0px 0px";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:17:"form-inputs-focus";a:5:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"form-buttons";a:9:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:15:"5px 5px 5px 5px";s:6:"shadow";s:23:"1px 1px 2px 0px #969696";s:7:"padding";s:17:"3px 10px 3px 10px";s:6:"margin";s:16:"10px 0px 0px 0px";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"form-buttons-hover";a:5:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:13:"toggle-button";a:9:{s:10:"background";s:20:"vertical, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:19:"toggle-button-hover";a:5:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:74:"1px solid #000000, 1px solid #000000, 1px solid #000000, 1px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"close-button";a:9:{s:10:"background";s:22:"horizontal, 0% #000000";s:5:"color";s:7:"#FFFFFF";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"close-button-hover";a:5:{s:10:"background";s:20:"vertical, 0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:4:"misc";a:1:{s:6:"custom";s:0:"";}}}';
		add_option($blackWhiteTopName, maybe_unserialize($blackWhiteTopData));
		wpoffcanvaspanels_styletool_add_theme_option($blackWhiteTopName);
	}

	//Dark
	$darkName = $style_tool_prefix . 'dark';
	if (!get_option($darkName)) {
		$darkData = 'a:3:{s:5:"title";s:4:"Dark";s:4:"slug";s:4:"dark";s:4:"data";a:15:{s:5:"panel";a:6:{s:5:"color";s:7:"#FFFFFF";s:6:"shadow";s:0:"";s:10:"background";s:20:"vertical, 0% #000000";s:7:"padding";s:4:"10px";s:6:"border";s:0:"";s:10:"text-align";s:0:"";}s:5:"links";a:5:{s:5:"color";s:7:"#FFFFFF";s:15:"text-decoration";s:0:"";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:11:"links-hover";a:5:{s:5:"color";s:0:"";s:15:"text-decoration";s:9:"underline";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:8:"headings";a:8:{s:5:"color";s:7:"#FFFFFF";s:14:"text-transform";s:0:"";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";s:6:"border";s:74:"0px solid #000000, 0px solid #000000, 1px solid #cccccc, 0px solid #000000";s:10:"text-align";s:0:"";s:6:"margin";s:15:"0px 0px 5px 0px";s:7:"padding";s:15:"0px 0px 5px 0px";}s:7:"widgets";a:5:{s:10:"background";s:0:"";s:6:"border";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:5:"color";s:0:"";}s:11:"form-labels";a:6:{s:5:"color";s:7:"#000000";s:15:"text-decoration";s:0:"";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";}s:11:"form-inputs";a:9:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:17:"0px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:17:"form-inputs-focus";a:5:{s:10:"background";s:0:"";s:5:"color";s:7:"#666666";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"form-buttons";a:9:{s:10:"background";s:10:"0% #FFFFFF";s:5:"color";s:7:"#000000";s:6:"border";s:17:"0px solid #000000";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"4px 4px 4px 4px";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"form-buttons-hover";a:5:{s:10:"background";s:20:"vertical, 0% #666666";s:5:"color";s:7:"#ffffff";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:13:"toggle-button";a:9:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:15:"5px 5px 5px 5px";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:19:"toggle-button-hover";a:5:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"close-button";a:9:{s:10:"background";s:20:"vertical, 0% #FFFFFF";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"close-button-hover";a:5:{s:10:"background";s:0:"";s:5:"color";s:7:"#666666";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:4:"misc";a:1:{s:6:"custom";s:0:"";}}}';
		add_option($darkName, maybe_unserialize($darkData));
		wpoffcanvaspanels_styletool_add_theme_option($darkName);
	}

	//Outer shadow
	$outerShadowName = $style_tool_prefix . 'outer-shadow';
	if (!get_option($outerShadowName)) {
		$outerShadowData = 'a:3:{s:5:"title";s:12:"Outer shadow";s:4:"slug";s:12:"outer-shadow";s:4:"data";a:15:{s:5:"panel";a:6:{s:5:"color";s:7:"#000000";s:6:"shadow";s:23:"0px 0px 5px 4px #bfbfbf";s:10:"background";s:10:"0% #FFFFFF";s:7:"padding";s:4:"10px";s:6:"border";s:0:"";s:10:"text-align";s:0:"";}s:5:"links";a:5:{s:5:"color";s:0:"";s:15:"text-decoration";s:0:"";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:11:"links-hover";a:5:{s:5:"color";s:0:"";s:15:"text-decoration";s:0:"";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";}s:8:"headings";a:7:{s:5:"color";s:0:"";s:14:"text-transform";s:0:"";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";s:6:"border";s:0:"";s:10:"text-align";s:0:"";s:6:"margin";s:0:"";}s:7:"widgets";a:5:{s:10:"background";s:0:"";s:6:"border";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:5:"color";s:0:"";}s:11:"form-labels";a:6:{s:5:"color";s:0:"";s:15:"text-decoration";s:0:"";s:14:"text-transform";s:0:"";s:11:"font-weight";s:0:"";s:9:"font-size";s:0:"";s:11:"text-shadow";s:0:"";}s:11:"form-inputs";a:9:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:17:"form-inputs-focus";a:5:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"form-buttons";a:9:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"form-buttons-hover";a:5:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:13:"toggle-button";a:9:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:19:"toggle-button-hover";a:5:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:12:"close-button";a:9:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";s:7:"padding";s:0:"";s:6:"margin";s:0:"";s:14:"text-transform";s:0:"";s:11:"text-shadow";s:0:"";}s:18:"close-button-hover";a:5:{s:10:"background";s:0:"";s:5:"color";s:0:"";s:6:"border";s:0:"";s:13:"border-radius";s:0:"";s:6:"shadow";s:0:"";}s:4:"misc";a:1:{s:6:"custom";s:0:"";}}}';
		add_option($outerShadowName, maybe_unserialize($outerShadowData));
		wpoffcanvaspanels_styletool_add_theme_option($outerShadowName);
	}
}